@@ -13,7 +13,7 @@ default_db_path = app_dir + "pydatasci_db.sqlite3"
 
 
 def check_exists_folder():
-	# If Windows does not have permission to read the folder, it will fail when trailing slashes \\ provided.
+	# If Windows does not have permission to read the folder, it will fail when trailing backslashes \\ provided.
 	app_dir_exists = os.path.exists(app_dir_free)
 	if app_dir_exists:
 		print("\n=> Success - the following file path already exists on your system:\n" + app_dir + "\n")
@@ -50,21 +50,58 @@ def create_folder():
 def check_permissions_folder():
 	app_dir_exists = check_exists_folder()
 	if app_dir_exists:
-		# https://www.geeksforgeeks.org/python-os-access-method/
-		readable = os.access(app_dir, os.R_OK)
-		writeable = os.access(app_dir, os.W_OK)
+		# Windows `os.access()` always returning True even when I have verify permissions are in fact denied.
+		if os.name == 'nt':
+			# Test write.
+			file_name = "pds_test_permissions.txt"
+			
+			try:
+				cmd_file_create = 'echo "test" >> ' + app_dir + file_name
+				write_response = os.system(cmd_file_create)
+			except:
+				print("\n=> Error - your operating system user does not have permission to write to file path:\n" + app_dir + "\n")
+				print("\n=> Fix - you can attempt to fix this by running `pds.grant_permissions_folder()`.\n")
+				raise
 
-		if readable and writeable:
-			print("\n=> Success - your operating system userID can read and write to file path:\n" + app_dir + "\n")
-			return True
-		else:
-			if not readable:
-				print("\n=> Error - your operating system userID does not have permission to read from file path:\n" + app_dir + "\n")
-			if not writeable:
-				print("\n=> Error - your operating system userID does not have permission to write to file path:\n" + app_dir + "\n")
-			if not readable or not writeable:
+			if write_response != 0:
+				print("\n=> Error - your operating system user does not have permission to write to file path:\n" + app_dir + "\n")
 				print("\n=> Fix - you can attempt to fix this by running `pds.grant_permissions_folder()`.\n")
 				return False
+			else:
+				# Test read.
+				try:
+					read_response = os.system("type " + app_dir + file_name)
+				except:
+					print("\n=> Error - your operating system user does not have permission to read from file path:\n" + app_dir + "\n")
+					print("\n=> Fix - you can attempt to fix this by running `pds.grant_permissions_folder()`.\n")
+					raise
+
+				if read_response != 0:
+					print("\n=> Error - your operating system user does not have permission to read from file path:\n" + app_dir + "\n")
+					print("\n=> Fix - you can attempt to fix this by running `pds.grant_permissions_folder()`.\n")
+					return False
+				else:
+					cmd_file_delete = "erase " + app_dir + file_name + " -Y"
+					os.system(cmd_file_delete)
+					print("\n=> Success - your operating system user can read from and write to file path:\n" + app_dir + "\n")
+
+		else:
+			# posix
+			# https://www.geeksforgeeks.org/python-os-access-method/
+			readable = os.access(app_dir, os.R_OK)
+			writeable = os.access(app_dir, os.W_OK)
+
+			if readable and writeable:
+				print("\n=> Success - your operating system user can read from and write to file path:\n" + app_dir + "\n")
+				return True
+			else:
+				if not readable:
+					print("\n=> Error - your operating system user does not have permission to read from file path:\n" + app_dir + "\n")
+				if not writeable:
+					print("\n=> Error - your operating system user does not have permission to write to file path:\n" + app_dir + "\n")
+				if not readable or not writeable:
+					print("\n=> Fix - you can attempt to fix this by running `pds.grant_permissions_folder()`.\n")
+					return False
 	else:
 		return False
 
